==> moodle_1.4.3.orig.tar.gz: moodle/lang/de/appointment.php <==
<?PHP // $Id$ 
      // appointment.php - created with Moodle 1.2 development (2004020300)


$string['allowresubmit'] = 'Wiederholung zulassen';
$string['appointmentdetails'] = 'Termindetails';
$string['appointmentlocation'] = 'Ort des Termins';
$string['appointmentname'] = 'Titel des Termins';
$string['date'] = 'Datum des Termins';
$string['description'] = 'Beschreibung';
$string['early'] = '$a frh';
$string['failedupdatefeedback'] = 'Update des Feedbacks fr Teilnehmer/in $a gescheitert';
$string['feedback'] = 'Feedback';
$string['feedbackupdated'] = 'Feedback fr $a Teilnehmer/innen aktualisiert';
$string['late'] = '$a spt';
$string['maximumgrade'] = 'Maximale Bewertung';
$string['maximumsize'] = 'Maximale Gre';
$string['modulename'] = 'Termin';
$string['modulenameplural'] = 'Termine';
$string['newsubmissions'] = 'Vorgeschlagene Termine';
$string['notgradedyet'] = 'Noch nicht bewertet';
$string['notsubmittedyet'] = 'Noch nicht  abgegeben';
$string['overwritewarning'] = 'Warnung: Neues Hochladen BERSCHREIBT die bisherige Arbeit';
$string['saveallfeedback'] = 'Mein gesamtes Feedback speichern';
$string['submissionfeedback'] = 'Feedback zur Arbeit';
$string['submissions'] = 'Arbeit';
$string['submitappointment'] = 'Formular zum Vorschlag eines Termins';
$string['submitted'] = 'Eingereicht';
$string['timeend'] = 'Ende des Termins';
$string['timestart'] = 'Anfang des Termins';
$string['typeoffline'] = 'Offline Aktivitt';
$string['typeuploadsingle'] = 'Eine einzelne Datei hochladen';
$string['uploadbadname'] = 'Dieser Dateiname enthlt unzulssige Zeichen. Sie kann nicht hochgeladen werden';
$string['uploadedfiles'] = 'Hochgeladene Dateien';
$string['uploaderror'] = 'Es ist ein Fehler beim Speichern auf dem Server aufgetreten';
$string['uploadfailnoupdate'] = 'Datei wurde hochgeladen, konnte aber die vorliegende Arbeit nicht aktualisieren';
$string['uploadfiletoobig'] = 'Sorry, aber diese Datei ist zu gro (Die Datei kann max. $a Byte gro sein)';
$string['uploadnofilefound'] = 'Es wurde keine Datei gefunden. Sind Sie sicher, dass Sie die richtige Datei ausgewhlt haben';
$string['uploadnotregistered'] = '\'$a\' wurde vollstndig hochgeladen. Die Arbeit wurde jedoch nicht registriert! Bitte wiederholen.';
$string['uploadsuccess'] = 'Upload \'$a\' erfolgreich';
$string['viewfeedback'] = 'Zeigt Bewertungen und Feedback an';
$string['viewsubmissions'] = 'Zeigt $a eingereichte Termine';
$string['yoursubmission'] = 'Ihre Einreichungen';

?>

==> moodle_1.5.2.orig.tar.gz: moodle/lang/de/appointment.php <==
<?PHP // $Id$ 
      // appointment.php - created with Moodle 1.4.3 (2004083130)


$string['allowresubmit'] = 'Wiederholung zulassen';
$string['appointmentdetails'] = 'Termindetails';
$string['appointmentlocation'] = 'Ort des Termins';
$string['appointmentname'] = 'Titel des Termins';
$string['date'] = 'Datum des Termins';
$string['description'] = 'Beschreibung';
$string['early'] = '$a frh';
$string['failedupdatefeedback'] = 'Update des Feedbacks fr Teilnehmer/in $a gescheitert';
$string['feedback'] = 'Feedback';
$string['feedbackupdated'] = 'Feedback fr $a Teilnehmer/innen aktualisiert';
$string['late'] = '$a spt';
$string['maximumgrade'] = 'Maximale Bewertung';
$string['maximumsize'] = 'Maximale Gre';
$string['modulename'] = 'Termin';
$string['modulenameplural'] = 'Termine';
$string['newsubmissions'] = 'Vorgeschlagene Termine';
$string['notgradedyet'] = 'Noch nicht bewertet';
$string['notsubmittedyet'] = 'Noch nicht  abgegeben';
$string['overwritewarning'] = 'Warnung: Neues Hochladen BERSCHREIBT die bisherige Arbeit';
$string['saveallfeedback'] = 'Mein gesamtes Feedback speichern';
$string['submissionfeedback'] = 'Feedback zur Arbeit';
$string['submissions'] = 'Arbeit';
$string['submitappointment'] = 'Formular zum Vorschlag eines Termins';
$string['submitted'] = 'Eingereicht';
$string['timeend'] = 'Ende des Termins';
$string['timestart'] = 'Anfang des Termins';
$string['typeoffline'] = 'Offline Aktivitt';
$string['typeuploadsingle'] = 'Eine einzelne Datei hochladen';
$string['uploadbadname'] = 'Dieser Dateiname enthlt unzulssige Zeichen. Sie kann nicht hochgeladen werden. Bitte benennen Sie die Datei um und versuchen es noch einmal.';
$string['uploadedfiles'] = 'Hochgeladene Dateien';
$string['uploaderror'] = 'Es ist ein Fehler beim Speichern auf dem Server aufgetreten';
$string['uploadfailnoupdate'] = 'Datei wurde hochgeladen, konnte aber die vorliegende Arbeit nicht aktualisieren';
$string['uploadfiletoobig'] = 'Sorry, aber diese Datei ist zu gro (Die Datei kann max. $a Byte gro sein)';
$string['uploadnofilefound'] = 'Es wurde keine Datei gefunden. Sind Sie sicher, dass Sie die richtige Datei ausgewhlt haben';
$string['uploadnotregistered'] = '\'$a\' wurde vollstndig hochgeladen. Die Arbeit wurde jedoch nicht registriert! Bitte wiederholen.';
$string['uploadsuccess'] = 'Upload \'$a\' erfolgreich';
$string['viewfeedback'] = 'Zeigt Bewertungen und Feedback an';
$string['viewsubmissions'] = 'Zeigt $a eingereichte Termine';
$string['yoursubmission'] = 'Ihre Einreichungen';

?>
